==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/Intune/ServiceDeviceSecurityGoogle.md <==
# ServiceDeviceSecurityGoogle


```text
azure-4/Item/Intune/ServiceDeviceSecurityGoogle
```

```text
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')
```



| Illustration | ServiceDeviceSecurityGoogle | ServiceDeviceSecurityGoogleCard | ServiceDeviceSecurityGoogleGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Intune/ServiceDeviceSecurityGoogle.png) | ![illustration for ServiceDeviceSecurityGoogle](../../../azure-4/Item/Intune/ServiceDeviceSecurityGoogle.Local.png) | ![illustration for ServiceDeviceSecurityGoogleCard](../../../azure-4/Item/Intune/ServiceDeviceSecurityGoogleCard.Local.png) | ![illustration for ServiceDeviceSecurityGoogleGroup](../../../azure-4/Item/Intune/ServiceDeviceSecurityGoogleGroup.Local.png) |




## ServiceDeviceSecurityGoogle

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogle
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogle('ServiceDeviceSecurityGoogle', 'Service Device Security Google', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogle
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogle('ServiceDeviceSecurityGoogle', 'Service Device Security Google', 'an optional tech label')
@enduml
```

## ServiceDeviceSecurityGoogleCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogleCard
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogleCard('ServiceDeviceSecurityGoogleCard', 'Service Device Security Google Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogleCard
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogleCard('ServiceDeviceSecurityGoogleCard', 'Service Device Security Google Card', 'an optional description')
@enduml
```

## ServiceDeviceSecurityGoogleGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogleGroup
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogleGroup('ServiceDeviceSecurityGoogleGroup', 'Service Device Security Google Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogleGroup
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogleGroup('ServiceDeviceSecurityGoogleGroup', 'Service Device Security Google Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/azure-4/Item/Intune/ServiceDeviceSecurityGoogle.md <==
# ServiceDeviceSecurityGoogle


```text
azure-4/Item/Intune/ServiceDeviceSecurityGoogle
```

```text
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')
```



| Illustration | ServiceDeviceSecurityGoogle | ServiceDeviceSecurityGoogleCard | ServiceDeviceSecurityGoogleGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Intune/ServiceDeviceSecurityGoogle.png) | ![illustration for ServiceDeviceSecurityGoogle](../../../azure-4/Item/Intune/ServiceDeviceSecurityGoogle.Local.png) | ![illustration for ServiceDeviceSecurityGoogleCard](../../../azure-4/Item/Intune/ServiceDeviceSecurityGoogleCard.Local.png) | ![illustration for ServiceDeviceSecurityGoogleGroup](../../../azure-4/Item/Intune/ServiceDeviceSecurityGoogleGroup.Local.png) |




## ServiceDeviceSecurityGoogle

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogle
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogle('ServiceDeviceSecurityGoogle', 'Service Device Security Google', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogle
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogle('ServiceDeviceSecurityGoogle', 'Service Device Security Google', 'an optional tech label')
@enduml
```

## ServiceDeviceSecurityGoogleCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogleCard
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogleCard('ServiceDeviceSecurityGoogleCard', 'Service Device Security Google Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogleCard
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogleCard('ServiceDeviceSecurityGoogleCard', 'Service Device Security Google Card', 'an optional description')
@enduml
```

## ServiceDeviceSecurityGoogleGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogleGroup
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogleGroup('ServiceDeviceSecurityGoogleGroup', 'Service Device Security Google Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDeviceSecurityGoogleGroup
include('azure-4/Item/Intune/ServiceDeviceSecurityGoogle')

' renders the element
ServiceDeviceSecurityGoogleGroup('ServiceDeviceSecurityGoogleGroup', 'Service Device Security Google Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
